summaryrefslogtreecommitdiffstats
path: root/core
diff options
context:
space:
mode:
authorsatok <satok@google.com>2011-08-03 18:44:54 +0900
committersatok <satok@google.com>2011-08-03 18:46:18 +0900
commitc66009169622ecdb65d887987feaf91fff091af8 (patch)
treea3333335e927400575dc7b05908399b68466bfe1 /core
parentf4461fc5a62658f5d150ca0ef2c135aef1236554 (diff)
downloadframeworks_base-c66009169622ecdb65d887987feaf91fff091af8.zip
frameworks_base-c66009169622ecdb65d887987feaf91fff091af8.tar.gz
frameworks_base-c66009169622ecdb65d887987feaf91fff091af8.tar.bz2
Rename API name "RESULT_ATTR_LOOKS_TYPO"
Change-Id: I42ab73513de20ea9a39af734b358094269ca7fe4
Diffstat (limited to 'core')
-rw-r--r--core/java/android/view/textservice/SuggestionsInfo.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/java/android/view/textservice/SuggestionsInfo.java b/core/java/android/view/textservice/SuggestionsInfo.java
index 3332f1e..ed0f89d 100644
--- a/core/java/android/view/textservice/SuggestionsInfo.java
+++ b/core/java/android/view/textservice/SuggestionsInfo.java
@@ -34,9 +34,9 @@ public final class SuggestionsInfo implements Parcelable {
/**
* Flag of the attributes of the suggestions that can be obtained by
* {@link #getSuggestionsAttributes}: this tells that the text service thinks the requested
* word looks a typo.
*/
- public static final int RESULT_ATTR_LOOKS_TYPO = 0x0002;
+ public static final int RESULT_ATTR_LOOKS_LIKE_TYPO = 0x0002;
private final int mSuggestionsAttributes;
private final String[] mSuggestions;
private final boolean mSuggestionsAvailable;
@@ -34,9 +34,9 @@ public final class SuggestionsInfo implements Parcelable {
* Flag of the attributes of the suggestions that can be obtained by
* {@link #getSuggestionsAttributes}: this tells that the text service thinks the requested
- * word looks a typo.
+ * word looks like a typo.
*/